==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/id.js <==
/**
 * Indonesian
 */

$.Editable.LANGS['id'] = {
  translation: {
    "Bold": "Tebal",
    "Italic": "Miring",
    "Underline": "Garis bawah",
    "Strikethrough": "Coret",
    "Font Size": "Ukuran leter",
    "Color": "Warna",
    "Background Color": "Warna latar belakang",
    "Text Color": "Warna teks",
    "Format Block": "Format",
    "Normal": "Normal",
    "Paragraph": "Paragraf",
    "Code": "Kode",
    "Quote": "Kutipan",
    "Heading 1": "Header 1",
    "Heading 2": "Header 2",
    "Heading 3": "Header 3",
    "Heading 4": "Header 4",
    "Heading 5": "Header 5",
    "Heading 6": "Header 6",
    "Alignment": "Penjajaran",
    "Align Left": "Rate kiri",
    "Align Center": "Rate tengah",
    "Align Right": "Rata kanan",
    "Justify": "Justifi",
    "Numbered List": "List nomor",
    "Bulleted List": "List simbol",
    "Indent Less": "Turunkan inden",
    "Indent More": "Tambah inden",
    "Select All": "Pilih semua",
    "Insert Link": "Memasukkan link",
    "Insert Image": "Memasukkan gambar",
    "Insert Video": "Memasukkan video",
    "Undo": "Batal",
    "Redo": "Ulang",
    "Show HTML": "Tampilkan HTML",
    "Float Left": "Kiri",
    "Float None": "Tak satupun",
    "Float Right": "Kanan",
    "Replace Image": "Mengganti gambar",
    "Remove Image": "Hapus gambar",
    "Title": "Judul",
    "Insert image": "Memasukkan gambar",
    "Drop image": "Jatuhkan gambar",
    "or click": "atau klik",
    "Enter URL": "Memasukkan URL",
    "Please wait!": "Silahkan tunggu!",
    "Are you sure? Image will be deleted.": "Apakah Anda yakin? Gambar akan dihapus.",
    "UNLINK": "Menghapus link",
    "Open in new tab": "Buka di tab baru",
    "Type something": "Ketik sesuatu",
    "Cancel": "Batal",
    "OK": "Ok",
    "Manage images": "Mengelola gambar",
    "Delete": "Hapus",
    "Font Family": "Jenis Huruf",
    "Insert Horizontal Line": "Sisipkan Garis Horizontal"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.1.tar.gz: django-froala-editor-0.8.1/froala_editor/static/froala_editor/js/langs/id.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Indonesian
 */

$.Editable.LANGS['id'] = {
  translation: {
    "Bold": "Tebal",
    "Italic": "Miring",
    "Underline": "Garis bawah",
    "Strikethrough": "Coret",
    "Font Size": "Ukuran leter",
    "Color": "Warna",
    "Background Color": "Warna latar belakang",
    "Text Color": "Warna teks",
    "Format Block": "Format",
    "Normal": "Normal",
    "Paragraph": "Paragraf",
    "Code": "Kode",
    "Quote": "Kutipan",
    "Heading 1": "Header 1",
    "Heading 2": "Header 2",
    "Heading 3": "Header 3",
    "Heading 4": "Header 4",
    "Heading 5": "Header 5",
    "Heading 6": "Header 6",
    "Alignment": "Penjajaran",
    "Align Left": "Rate kiri",
    "Align Center": "Rate tengah",
    "Align Right": "Rata kanan",
    "Justify": "Justifi",
    "Numbered List": "List nomor",
    "Bulleted List": "List simbol",
    "Indent Less": "Turunkan inden",
    "Indent More": "Tambah inden",
    "Select All": "Pilih semua",
    "Insert Link": "Memasukkan link",
    "Insert Image": "Memasukkan gambar",
    "Insert Video": "Memasukkan video",
    "Undo": "Batal",
    "Redo": "Ulang",
    "Show HTML": "Tampilkan HTML",
    "Float Left": "Kiri",
    "Float None": "Tak satupun",
    "Float Right": "Kanan",
    "Replace Image": "Mengganti gambar",
    "Remove Image": "Hapus gambar",
    "Title": "Judul",
    "Insert image": "Memasukkan gambar",
    "Drop image": "Jatuhkan gambar",
    "or click": "atau klik",
    "Enter URL": "Memasukkan URL",
    "Please wait!": "Silahkan tunggu!",
    "Are you sure? Image will be deleted.": "Apakah Anda yakin? Gambar akan dihapus.",
    "UNLINK": "Menghapus link",
    "Open in new tab": "Buka di tab baru",
    "Type something": "Ketik sesuatu",
    "Cancel": "Batal",
    "OK": "Ok",
    "Manage images": "Mengelola gambar",
    "Delete": "Hapus",
    "Font Family": "Jenis Huruf",
    "Insert Horizontal Line": "Sisipkan Garis Horizontal",
    "Table": "Tabel",
    "Insert table": "Sisipkan tabel",
    "Cell": "Sel",
    "Row": "Baris",
    "Column": "Kolom",
    "Delete table": "Hapus table",
    "Insert cell before": "Sisipkan sel sebelum",
    "Insert cell after": "Sisipkan sel setelah",
    "Delete cell": "Hapus sel",
    "Merge cells": "Menggabungkan sel",
    "Horizontal split": "Perpecahan horisontal",
    "Vertical split": "perpecahan vertikal",
    "Insert row above": "Sisipkan baris di atas",
    "Insert row below": "Sisipkan baris di bawah",
    "Delete row": "Hapus baris",
    "Insert column before": "Sisipkan kolom sebelum",
    "Insert column after": "Sisipkan kolom setelah",
    "Delete column": "Hapus kolom"
  },
  direction: "ltr"
};
